pub struct DefaultEngine { /* private fields */ }Expand description
The default engine used when defining a test target
Engine implementation which mimics Rust’s default test
harness. By default, the test inputs will include any present
corpus and crashes files, as well as generating
Implementations
Sourceimpl TestEngine
impl TestEngine
pub fn new(location: TargetLocation) -> Self
pub fn with_test_time(&mut self, test_time: Duration) -> &mut Self
pub fn with_iterations(&mut self, iterations: usize) -> &mut Self
pub fn with_max_len(&mut self, max_len: usize) -> &mut Self